{{ header }}

.. _user_guide:

==========
User Guide
==========

The User Guide covers all of pandas by topic area. Each of the subsections
introduces a topic (such as "working with missing data"), and discusses how
pandas approaches the problem, with many examples throughout.

Users brand-new to pandas should start with :ref:`10min`.

Further information on any specific method can be obtained in the
:ref:`api`.

.. If you update this toctree, also update the manual toctree in the
   main index.rst.template

.. toctree::
    :maxdepth: 2

    io
    indexing
    advanced
    merging
    reshaping
    text
    missing_data
    categorical
    integer_na
    visualization
    computation
    groupby
    timeseries
    timedeltas
    style
    options
    enhancingperf
    sparse
    gotchas
    cookbook
